@@ -1,4 +1,4 @@
-from typing import Dict
+from typing import Dict, Optional
 from marshmallow import Schema, fields, validate, validates, ValidationError
 
 
@@ -8,6 +8,15 @@ class CloudProviderConfigValidator(Schema):
     region_name = fields.String(required=True)
     aws_access_key_id = fields.String()
     aws_secret_access_key = fields.String()
+    endpoint_url = fields.String()
+
+    @validates("endpoint_url")
+    def validate_endpoint_url(self, value: Optional[str]):
+        if value is None:
+            return
+        if not value.startswith(("http", "https")):
+            raise ValidationError("endpoint url must be in http or https")
+
 
 class CloudQueueWorkerValidator(Schema):
     queue_mapping = fields.Dict(required=True)
